# Script to process validation data files in directories and assign 
# labels to them reflecting the tune name (first-letter uppercase of 
# directory names). 

#!/bin/sh
# Note the $10 may need to be $9 on some systems, depending on ls -l output
# (One further change then needs to be done below, under FILES=...)
DIRS=`ls -l | egrep '^d' | awk '{print $10}'`

echo DIRS = $DIRS

# "ls -l $MYDIR"      = get a directory listing
# "| egrep '^d'"           = pipe to egrep and select only the directories
# "awk '{print $8}'" = pipe the result from egrep to awk and print only the 8th field

# and now loop through the directories:
for DIR in $DIRS
do
  # Old structure, where the SRC attribute was defined by the directory name.
  # Now changed to use file-by-file version names (more acurate)
  #SRC=`echo ${DIR:0:1} | tr  '[a-z]' '[A-Z]'`${DIR:1}
  #SRC=`echo ${SRC} | sed s/-/" "/`
  echo Processing Directory ${DIR}
  FILES=`ls -l $DIR | egrep 'dat' | awk '{print $10}'`
  cd $DIR 
  for FILE in $FILES
  do      
      if [ -r ${FILE} ]; then
# Change the line with SRC to 
      SRC=`cat ${FILE} | grep "REF = " | cut -d"=" -f2 | cut -d"+" -f1`
      # Verbose output: write out what SRC becomes for each file
      #echo "  " $DIR/$FILE was generated with $SRC
      cat ${FILE} | sed "s/SRC.*/SRC =${SRC}/" > tmp.out
      chmod 666 $FILE 
      mv tmp.out $FILE
      chmod 444 $FILE
    fi
  done
  cd ../
done

